Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CPIVersionInfo ¶
type CPIVersionInfo struct {
// VsphereVersion defines the min and max version for vSphere
VSphereVersion VersionRange `json:"vSphere"`
// k8sVersion defines the skewVersion for k8s
K8sVersion SkewVersion `json:"k8s"`
// DeploymentPaths defines list of deployment URLs
DeploymentPaths []string `json:"deploymentPath"`
}
CPIVersionInfo defines the CPI Config Specs for various versions
type CSIVersionInfo ¶
type CSIVersionInfo struct {
// VsphereVersion defines the min and max version for vSphere
VSphereVersion VersionRange `json:"vSphere"`
// k8sVersion defines the skewVersion for k8s
K8sVersion VersionRange `json:"k8s"`
// IsCPIRequired is a flag to check if CPI needs to be configured
IsCPIRequired bool `json:"isCPIRequired"`
// DeploymentPaths defines list of deployment URLs
DeploymentPaths []string `json:"deploymentPath"`
}
CSIVersionInfo defines the CPI Config Specs for various versions
type CompatMatrix ¶
type CompatMatrix struct {
// CSISpecList defines list of CSI Version Specs
CSISpecList map[string]CSIVersionInfo `json:"CSI"`
// CPISpecList defines the list of CPI Version Specs
CPISpecList map[string]CPIVersionInfo `json:"CPI"`
}
Matrix defines the Spec List for CPI and CSI
type SkewVersion ¶
type SkewVersion struct {
SkewVersion string `json:"skewVersion"`
}
SkewVersion defines the skew version for k8s
type VersionRange ¶
type VersionRange struct {
// Min defines the minimum required version
Min string `json:"min"`
// Max defines the maximum required version
Max string `json:"max"`
}
VersionRange defines the min and max version
Click to show internal directories.
Click to hide internal directories.